@@ -2,7 +2,7 @@ import requests
 import json
 
 
-def error_handler(resource):
+def error_handler(response):
     print(f"Status: {response.status_code}")
     print(f"ErrorMessage: {response.json()['error']}")
     return {response.json()['error']}
